@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2002, 2004 Zope Corporation and Contributors.
+# Copyright (c) 2009 Zope Corporation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -13,15 +13,15 @@
 ##############################################################################
 """Bootstrap code for principal annotation utility.
 
-$Id: bootstrap.py 97527 2009-03-05 12:21:09Z nadako $
+$Id: bootstrap.py 97701 2009-03-09 15:10:31Z nadako $
 """
 
 import transaction
 
 from zope.app.appsetup.bootstrap import ensureUtility, getInformationFromEvent
 
-from zope.app.principalannotation import PrincipalAnnotationUtility
-from zope.app.principalannotation.interfaces import IPrincipalAnnotationUtility
+from zope.principalannotation.utility import PrincipalAnnotationUtility
+from zope.principalannotation.interfaces import IPrincipalAnnotationUtility
 
 def bootStrapSubscriber(event):
     """Subscriber to the IDatabaseOpenedWithRootEvent
